MultiSampleEdge

Struct MultiSampleEdge 

pub struct MultiSampleEdge { /* private fields */ }
Edge class for connecting nodes in the graph that tracks some per-sample information.

This class extends BaseEdge with the additional functionality of tracking the maximum multiplicity seen within any single sample. The workflow for using this class is:

{@code
     MultiSampleEdge e = new MultiSampleEdge(ref, 1)
     e.incMultiplicity(1)              // total is 2, per sample is 2, max per sample is 1
     e.getPruningMultiplicity()        // = 1
     e.flushSingleSampleMultiplicity() // total is 2, per sample is 0, max per sample is 2
     e.getPruningMultiplicity()        // = 2
     e.incMultiplicity(3)              // total is 5, per sample is 3, max per sample is 2
     e.getPruningMultiplicity()        // = 2
     e.flushSingleSampleMultiplicity() // total is 5, per sample is 0, max per sample is 3
     e.getPruningMultiplicity()        // = 3
}

Implementations

Source

impl MultiSampleEdge

pub fn set( &mut self, is_ref: bool, multiplicity: usize, single_sample_capacity: usize, )

pub fn flush_single_sample_multiplicity(&mut self)

update the single sample multiplicities by adding the current single sample multiplicity to the priority queue, and reset the current single sample multiplicity to 0.

pub fn inc_multiplicity(&mut self, incr: usize)

pub fn get_pruning_multiplicity(&self) -> usize

pub fn add_reference_index(&mut self, i: usize)

pub fn get_reference_path_indexes(&self) -> &Vec<usize>

pub fn get_current_single_sample_multiplicity(&self) -> usize