pub struct ReferenceReader {
pub current_sequence: Vec<u8>,
pub genomes_and_contigs: GenomesAndContigs,
pub target_lens: HashMap<usize, u64>,
/* private fields */
}Expand description
Struct handling methods to read and handle information for references
indexed_reader represents the #IndexedReader
Fields
current_sequence: Vec<u8>genomes_and_contigs: GenomesAndContigstarget_lens: HashMap<usize, u64>Implementations
Sourceimpl ReferenceReader
impl ReferenceReader
pub fn new( concatenated_genomes: &Option<String>, genomes_and_contigs: GenomesAndContigs, _number_of_contigs: usize, ) -> ReferenceReader
pub fn new_with_target_names( concatenated_genomes: &Option<String>, genomes_and_contigs: GenomesAndContigs, target_names: Vec<&[u8]>, ) -> Self
Sourcepub fn new_from_reader_with_reference_index(
reader: &Self,
ref_idx: usize,
) -> Self
pub fn new_from_reader_with_reference_index( reader: &Self, ref_idx: usize, ) -> Self
Somewhat efficient cloning function. Only takes the info needed for a given ref idx
pub fn new_from_reader_with_tid_and_rid( reader: &ReferenceReader, ref_idx: usize, tid: usize, ) -> Self
pub fn get_target_name(&self, tid: usize) -> &[u8] ⓘ
pub fn add_target(&mut self, target: &[u8], tid: usize)
pub fn update_ref_index_tids(&mut self, ref_index: usize, tid: usize) -> usize
pub fn retrieve_tids_for_ref_index( &self, ref_index: usize, ) -> Option<&LinkedHashSet<usize>>
pub fn add_length(&mut self, tid: usize, length: u64)
pub fn add_lengths(&mut self, target_lengths: HashMap<usize, u64>)
pub fn get_contig_length(&self, tid: usize) -> u64
pub fn retrieve_reference_stem(&self, ref_idx: usize) -> String
pub fn update_current_sequence_capacity(&mut self, size: usize)
pub fn update_current_sequence_without_capacity(&mut self)
pub fn retrieve_contig_name_from_tid(&self, tid: usize) -> Option<&Vec<u8>>
pub fn fetch_contig_from_reference_by_contig_name( &mut self, contig_name: &[u8], ref_idx: usize, )
pub fn fetch_contig_from_reference_by_tid( &mut self, tid: usize, ref_idx: usize, ) -> Result<(), Error>
Sourcepub fn fetch_reference_context(
&mut self,
ref_idx: usize,
interval: &SimpleInterval,
)
pub fn fetch_reference_context( &mut self, ref_idx: usize, interval: &SimpleInterval, )
Fetches the reference sequence from a given SimpleInterval The return position is 0-base start and stop inclusive
pub fn read_sequence_to_vec(&mut self)