pub struct ReferenceWriter<'a> { /* private fields */ }Expand description
Struct housing methods for writing out genomes when given specific variant information Basically a wrapper for reference reader
Implementations
Sourceimpl<'a> ReferenceWriter<'a>
impl<'a> ReferenceWriter<'a>
pub fn new( reference_reader: ReferenceReader, output_prefix: &'a str, ) -> ReferenceWriter<'a>
Sourcepub fn generate_strains(
&mut self,
variant_contexts: Vec<VariantContext>,
ref_idx: usize,
strain_ids_present: Vec<usize>,
)
pub fn generate_strains( &mut self, variant_contexts: Vec<VariantContext>, ref_idx: usize, strain_ids_present: Vec<usize>, )
Generates the potential strain genomes calculated by Lorikeet. The VariantContexts are expected
To be tagged with one or more strain genomes in their attributes with VariantAnnotation::Strain
tag
Sourcepub fn generate_consensus(
&mut self,
variant_contexts: Vec<VariantContext>,
ref_idx: usize,
samples: &[&str],
)
pub fn generate_consensus( &mut self, variant_contexts: Vec<VariantContext>, ref_idx: usize, samples: &[&str], )
Generates the per sample consensus genomes based on the provided variant contexts. The consensus is defined as the most dominant variant at a given position on the reference genome measured by read depth.
pub fn modify_reference_bases_based_on_variant_type( new_bases: &mut Vec<u8>, consensus_allele: ByteArrayAllele, vc: &mut VariantContext, variant_type: VariantType, offset: &mut i64, )