pub struct VariantAnnotationEngine {}Expand description
The class responsible for computing annotations for variants. Annotations are auto-discovered - ie, any class that extends {@link VariantAnnotation} and lives in this package is treated as an annotation and the engine will attempt to create instances of it by calling the non-arg constructor (loading will fail if there is no no-arg constructor).
Implementations
Sourceimpl VariantAnnotationEngine
impl VariantAnnotationEngine
Sourcepub fn annotate_context<A: Allele>(
vc: &VariantContext,
read_likelihoods: &mut AlleleLikelihoods<A>,
add_annotation: Box<dyn Fn(&Annotation) -> bool>,
) -> VariantContext
pub fn annotate_context<A: Allele>( vc: &VariantContext, read_likelihoods: &mut AlleleLikelihoods<A>, add_annotation: Box<dyn Fn(&Annotation) -> bool>, ) -> VariantContext
Annotates the given variant context - adds all annotations that satisfy the predicate. NOTE: Due to trait impl limitations. read_likelihoods should be marginalized over the alleles in vc BEFORE being passed to this function. GATK HaplotypeCaller Marginalizes inside function, but this is not possible with current setup as it we want general functions :) @param vc the variant context to annotate @param features context containing the features that overlap the given variant @param ref the reference context of the variant to annotate or null if there is none @param readLikelihoods readLikelihoods indexed by sample, allele, and read within sample. May be null @param addAnnot function that indicates if the given annotation type should be added to the variant
Sourcepub fn vc_annotations() -> Vec<Annotation>
pub fn vc_annotations() -> Vec<Annotation>
Annotations added to the VariantContext
Sourcepub fn genotype_annotations() -> Vec<Annotation>
pub fn genotype_annotations() -> Vec<Annotation>
Annotations added to the Genotype of VariantContexts
Sourcepub fn precalculated_annotations() -> Vec<Annotation>
pub fn precalculated_annotations() -> Vec<Annotation>
Annotations that are precalculated or calculated through other annotations
Sourcepub fn populate_vcf_header(header: &mut Header, strain_info: bool)
pub fn populate_vcf_header(header: &mut Header, strain_info: bool)
Populates a given VCF header with all possible annotation fields and info