pub struct ReadThreadingAssembler { /* private fields */ }Implementations
Sourceimpl ReadThreadingAssembler
impl ReadThreadingAssembler
pub fn new( max_allowed_paths_for_read_threading_assembler: i32, kmer_sizes: Vec<usize>, dont_increase_kmer_sizes_for_cycles: bool, allow_non_unique_kmers_in_ref: bool, num_pruning_samples: i32, prune_factor: usize, use_adaptive_pruning: bool, initial_error_rate_for_pruning: f64, pruning_log_odds_threshold: f64, pruning_seeding_log_odds_threshold: f64, max_unpruned_variants: usize, _use_linked_debruijn_graphs: bool, enable_legacy_graph_cycle_detection: bool, min_matching_bases_to_dangle_end_recovery: i32, disable_prune_factor_correction: bool, ) -> ReadThreadingAssembler
pub fn default() -> Self
pub fn default_with_kmers( max_allowed_paths_for_read_threading_assembler: i32, kmer_sizes: Vec<usize>, prune_factor: usize, ) -> Self
pub fn set_just_return_raw_graph(&mut self, value: bool)
pub fn set_remove_paths_not_connected_to_ref(&mut self, value: bool)
pub fn set_recover_dangling_branches(&mut self, value: bool)
Sourcepub fn run_local_assembly<'b>(
&mut self,
assembly_region: AssemblyRegion,
ref_haplotype: &'b mut Haplotype<SimpleInterval>,
full_reference_with_padding: Vec<u8>,
ref_loc: SimpleInterval,
sample_names: &'b [String],
dangling_end_sw_parameters: Parameters,
reference_to_haplotype_sw_parameters: Parameters,
avx_mode: AVXMode,
additional_kmer_sizes: Option<Vec<usize>>,
) -> AssemblyResultSet<ReadThreadingGraph>
pub fn run_local_assembly<'b>( &mut self, assembly_region: AssemblyRegion, ref_haplotype: &'b mut Haplotype<SimpleInterval>, full_reference_with_padding: Vec<u8>, ref_loc: SimpleInterval, sample_names: &'b [String], dangling_end_sw_parameters: Parameters, reference_to_haplotype_sw_parameters: Parameters, avx_mode: AVXMode, additional_kmer_sizes: Option<Vec<usize>>, ) -> AssemblyResultSet<ReadThreadingGraph>
Main entry point into the assembly engine. Build a set of deBruijn graphs out of the provided reference sequence and list of reads @param assemblyRegion AssemblyRegion object holding the reads which are to be used during assembly @param refHaplotype reference haplotype object @param fullReferenceWithPadding byte array holding the reference sequence with padding @param refLoc GenomeLoc object corresponding to the reference sequence with padding @param readErrorCorrector a ReadErrorCorrector object, if read are to be corrected before assembly. Can be null if no error corrector is to be used. @param aligner {@link SmithWatermanAligner} used to align dangling ends in assembly graphs to the reference sequence @return the resulting assembly-result-set
Sourcepub fn assemble<'b>(
&mut self,
reads: &'b Vec<BirdToolRead>,
ref_haplotype: &'b Haplotype<SimpleInterval>,
sample_names: &'b [String],
dangling_end_sw_parameters: &Parameters,
avx_mode: AVXMode,
additional_kmer_sizes: Option<Vec<usize>>,
) -> Vec<AssemblyResult<SimpleInterval, ReadThreadingGraph>>
pub fn assemble<'b>( &mut self, reads: &'b Vec<BirdToolRead>, ref_haplotype: &'b Haplotype<SimpleInterval>, sample_names: &'b [String], dangling_end_sw_parameters: &Parameters, avx_mode: AVXMode, additional_kmer_sizes: Option<Vec<usize>>, ) -> Vec<AssemblyResult<SimpleInterval, ReadThreadingGraph>>
Given reads and a reference haplotype give us graphs to use for constructing non-reference haplotypes.
@param reads the reads we’re going to assemble @param refHaplotype the reference haplotype @param aligner {@link SmithWatermanAligner} used to align dangling ends in assembly graphs to the reference sequence @return a non-null list of reads